@@ -3,7 +3,7 @@ import os
 
 __ROOT__ = os.path.dirname(os.path.abspath(__file__))
 
-from .encoder import BertEncoder, LongTextEncoder
+from .encoder import BertEncoder, LongTextEncoder, LongformerEncoder
 from .nn import LinearRegression, LogisticRegression, SoftmaxRegression
 from .trainer import TextBinaryClassifierTrainer
 
